@@ -12,7 +12,7 @@ use base qw(Net::DNS::Resolver::Base DynaLoader), OS_CONF;
 our $VERSION;
 
 BEGIN {
-	$VERSION = '1.25_03';
+	$VERSION = '1.26_01';
 	eval { __PACKAGE__->bootstrap($VERSION) };
 }
 
@@ -303,7 +303,7 @@ or other platform-specific sources.
 
 sub resolv_conf {
 	my ( $self, $filename ) = @_;
-	return $self->_config( 'resolv_conf', $filename );
+	return $self->_config( 'resolvconf', $filename );
 }
 
 
@@ -379,7 +379,7 @@ Pass the name of a BIND-style config file containing trusted-keys{}.
 
 sub trusted_keys {
 	my ( $self, $filename ) = @_;
-	return $self->_config( 'trusted_keys', $filename );
+	return $self->_config( 'trustedkeys', $filename );
 }
 
 
@@ -394,7 +394,7 @@ Pass a null argument to disable. Default is stderr.
 
 sub debug_out {
 	my ( $self, $stream ) = @_;
-	return $self->_config( 'debug_out', $stream );
+	return $self->_config( 'debugout', $stream );
 }
 
 
@@ -410,7 +410,7 @@ Set verbosity of the debug output directed to stderr.  Level 0 is off,
 sub debug_level {
 	my ( $self, $verbosity ) = @_;
 	$self->debug($verbosity);
-	return $self->_config( 'debug_level', $verbosity );
+	return $self->_config( 'debuglevel', $verbosity );
 }
 
 
